@@ -1,9 +1,9 @@
-t_notebook = "api"
-t_static = "static"
-t_task = "tasks"
+t_notebook = "notebook"
+t_asset = "asset"
 t_dependency = "dependency"
 t_scheduler = "scheduler"
 
+t_job = "job"
 t_add = "installed"
 t_delete = "delete"
 t_update = "edited"
